@@ -2,16 +2,16 @@
 __all__ = ["Group", "User"]
 
 from kokki.base import *
-from kokki.environment import env
 
 class Group(Resource):
     action = ForcedListArgument(default="create")
     group_name = ResourceArgument(default=lambda obj:obj.name)
     gid = ResourceArgument()
-    # members = ForcedListArgument() # NOT SUPPORTED
+    members = ForcedListArgument()
+    password = ResourceArgument()
     # append = BooleanArgument(default=False) # NOT SUPPORTED
 
-    actions = Resource.actions + ["create", "remove", "Modify", "manage", "lock", "unlock"]
+    actions = Resource.actions + ["create", "remove", "modify", "manage", "lock", "unlock"]
 
 class User(Resource):
     action = ForcedListArgument(default="create")
@@ -19,8 +19,10 @@ class User(Resource):
     comment = ResourceArgument()
     uid = ResourceArgument()
     gid = ResourceArgument()
+    groups = ForcedListArgument() # supplementary groups
     home = ResourceArgument()
-    shell = ResourceArgument()
+    shell = ResourceArgument(default="/bin/bash")
     password = ResourceArgument()
+    system = BooleanArgument(default=False)
 
-    actions = Resource.actions + ["create", "remove", "Modify", "manage", "lock", "unlock"]
+    actions = Resource.actions + ["create", "remove", "modify", "manage", "lock", "unlock"]
